@@ -113,7 +113,7 @@ gda_g_type_to_string (GType type)
  *   <listitem><para>"null" for GDA_TYPE_NULL</para></listitem>
  * </itemizedlist>
  *
- * Returns: the #GType represented by the given @str, or #G_TYPE_INVALID if not found
+ * Returns: the #GType represented by the given @str.
  */
 GType
 gda_g_type_from_string (const gchar *str)
@@ -154,7 +154,7 @@ gda_g_type_from_string (const gchar *str)
  * @string: string to escape
  *
  * Escapes @string to make it understandable by a DBMS. The escape method is very common and replaces any
- * occurence of "'" with "''" and "\" with "\\"
+ * occurrence of "'" with "''" and "\" with "\\"
  *
  * Returns: a new string
  */
@@ -589,7 +589,6 @@ gda_utility_holder_load_attributes (GdaHolder *holder, xmlNodePtr node, GSList *
 				}
 			}
 		}
-		g_free (source);
 	}
 
 	/* specified value */
@@ -706,7 +705,7 @@ gda_text_to_alphanum (const gchar *text)
  *
  * Does the opposite of gda_text_to_alphanum(), in the same string 
  *
- * Returns: @text if conversion succedded or %NULL if an error occurred
+ * Returns: @text if conversion succeeded or %NULL if an error occurred
  */
 gchar *
 gda_alphanum_to_text (gchar *text)
@@ -858,7 +857,6 @@ gda_compute_unique_table_row_condition_with_cnc (GdaConnection *cnc, GdaSqlState
 				GdaSqlOperation *op;
 				GdaSqlExpr *opexpr;
 				GdaSqlParamSpec *pspec;
-				gchar *str;
 
 				/* equal condition */
 				if (and_cond) {
@@ -873,6 +871,7 @@ gda_compute_unique_table_row_condition_with_cnc (GdaConnection *cnc, GdaSqlState
 				}
 				op->operator_type = GDA_SQL_OPERATOR_TYPE_EQ;
 				/* left operand */
+				gchar *str;
 				opexpr = gda_sql_expr_new (GDA_SQL_ANY_PART (op));
 				str = gda_sql_identifier_quote (tcol->column_name, cnc, NULL, FALSE, FALSE);
 				g_value_take_string (opexpr->value = gda_value_new (G_TYPE_STRING), str);
@@ -955,8 +954,6 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
         GdaSqlStatement *sql_dst = NULL;
         GdaSqlStatementDelete *dst = NULL;
 
-	gchar *tmp;
-
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 	g_return_val_if_fail (GDA_IS_STATEMENT (select_stmt), FALSE);
 	g_return_val_if_fail (gda_statement_get_statement_type (select_stmt) == GDA_SQL_STATEMENT_SELECT, FALSE);
@@ -983,6 +980,7 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 	target = (GdaSqlSelectTarget*) stsel->from->targets->data;
 	
 	/* actual statement structure's computation */
+	gchar *tmp;
 	tmp = gda_sql_identifier_quote (target->table_name, cnc, NULL, FALSE, FALSE);
 	if (insert_stmt) {
 		sql_ist = gda_sql_statement_new (GDA_SQL_STATEMENT_INSERT);
@@ -990,7 +988,7 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 		g_assert (GDA_SQL_ANY_PART (ist)->type == GDA_SQL_ANY_STMT_INSERT);
 
 		ist->table = gda_sql_table_new (GDA_SQL_ANY_PART (ist));
-		ist->table->table_name = g_strdup (tmp);
+		ist->table->table_name = g_strdup ((gchar *) target->table_name);
 	}
 	
 	if (update_stmt) {
@@ -1005,11 +1003,9 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 									     require_pk, error);
 		if (!ust->cond) {
 			retval = FALSE;
-			*update_stmt = NULL;
-			update_stmt = NULL; /* don't try anymore to build UPDATE statement */
+			goto cleanup;
 		}
-		else
-			GDA_SQL_ANY_PART (ust->cond)->parent = GDA_SQL_ANY_PART (ust);
+		GDA_SQL_ANY_PART (ust->cond)->parent = GDA_SQL_ANY_PART (ust);
 	}
         
 	if (delete_stmt) {
@@ -1019,19 +1015,14 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 
 		dst->table = gda_sql_table_new (GDA_SQL_ANY_PART (dst));
 		dst->table->table_name = g_strdup (tmp);
-		if (update_stmt && ust->cond)
-			dst->cond = gda_sql_expr_copy (ust->cond);
-		else
-			dst->cond = gda_compute_unique_table_row_condition_with_cnc (cnc, stsel, 
+		dst->cond = gda_compute_unique_table_row_condition_with_cnc (cnc, stsel, 
 									     GDA_META_TABLE (target->validity_meta_object),
 									     require_pk, error);
 		if (!dst->cond) {
 			retval = FALSE;
-			*delete_stmt = NULL;
-			delete_stmt = NULL; /* don't try anymore to build DELETE statement */
+			goto cleanup;
 		}
-		else
-			GDA_SQL_ANY_PART (dst->cond)->parent = GDA_SQL_ANY_PART (dst);
+		GDA_SQL_ANY_PART (dst->cond)->parent = GDA_SQL_ANY_PART (dst);
 	}
 	g_free (tmp);
 
@@ -1058,16 +1049,15 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 		if (insert_stmt) {
 			GdaSqlField *field;
 			field = gda_sql_field_new (GDA_SQL_ANY_PART (ist));
-			field->field_name = g_strdup (str);
+			field->field_name = g_strdup (selfield->field_name);
 			ist->fields_list = g_slist_append (ist->fields_list, field);
 		}
 		if (update_stmt) {
 			GdaSqlField *field;
 			field = gda_sql_field_new (GDA_SQL_ANY_PART (ust));
-			field->field_name = g_strdup (str);
+			field->field_name = g_strdup (selfield->field_name);
 			ust->fields_list = g_slist_append (ust->fields_list, field);
 		}
-		g_free (str);
 
 		/* parameter for the inserted value */
 		GdaSqlExpr *expr;
@@ -1104,11 +1094,10 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 			g_set_error (error, GDA_SQL_ERROR, GDA_SQL_STRUCTURE_CONTENTS_ERROR,
 				     "%s", _("Could not compute any field to insert into"));
 			retval = FALSE;
+			goto cleanup;
 		}
-		else {
-			ist->values_list = g_slist_append (NULL, insert_values_list);
-			ret_insert = g_object_new (GDA_TYPE_STATEMENT, "structure", sql_ist, NULL);
-		}
+		ist->values_list = g_slist_append (NULL, insert_values_list);
+		ret_insert = g_object_new (GDA_TYPE_STATEMENT, "structure", sql_ist, NULL);
 	}
 	if (update_stmt)
 		ret_update = g_object_new (GDA_TYPE_STATEMENT, "structure", sql_ust, NULL);
@@ -1140,7 +1129,7 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
  *
  * Computes a SELECT statement which selects all the rows the @update_stmt would update. Beware
  * however that this GdaSqlStatement does not select anything (ie it would be rendered as "SELECT FROM ... WHERE ...")
- * and before being useable, one needs to add some fields to actually select.
+ * and before being usable, one needs to add some fields to actually select.
  *
  * Returns; a new #GdaStatement if no error occurred, or %NULL otherwise
  */
@@ -1175,8 +1164,7 @@ gda_compute_select_statement_from_update (GdaStatement *update_stmt, GError **er
 	target = gda_sql_select_target_new (GDA_SQL_ANY_PART (sst->from));
 	sst->from->targets = g_slist_prepend (NULL, target);
 	target->expr = gda_sql_expr_new (GDA_SQL_ANY_PART (target));
-	g_value_set_string ((target->expr->value = gda_value_new (G_TYPE_STRING)),
-			    ust->table->table_name);
+	g_value_set_string ((target->expr->value = gda_value_new (G_TYPE_STRING)), ust->table->table_name);
 
 	/* WHERE */
 	sst->where_cond = gda_sql_expr_copy (ust->cond);
@@ -1319,12 +1307,6 @@ prepare_sql_identifier_for_compare (gchar *str)
 	}
 }
 
-static gint
-cmp_func (gconstpointer a, gconstpointer b)
-{
-	return g_strcmp0 (*((gchar**) a), *((gchar**) b));
-}
-
 /**
  * gda_completion_list_get
  * @cnc: a #GdaConnection object
@@ -1348,8 +1330,6 @@ gda_completion_list_get (GdaConnection *cnc, const gchar *sql, gint start, gint
 	if (!cnc) 
 		return NULL;
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
-	if (!sql || !(*sql))
-		return NULL;
 	if (end < start)
 		return NULL;
 
@@ -1502,7 +1482,7 @@ gda_completion_list_get (GdaConnection *cnc, const gchar *sql, gint start, gint
 						
 						g_object_unref (m2);
 					}
-					g_free (str);
+					free (str);
 				}
 			}
 		}
@@ -1536,23 +1516,6 @@ gda_completion_list_get (GdaConnection *cnc, const gchar *sql, gint start, gint
 	g_free (text);
 	if (compl) {
 		if (compl->len >= 1) {
-			/* sort */
-			gint i;
-			g_array_sort (compl, cmp_func);
-
-			/* remove duplicates if any */
-			for (i = 1; i < compl->len; ) {
-				gchar *current, *before;
-				current = g_array_index (compl, gchar*, i);
-				before = g_array_index (compl, gchar*, i - 1);
-				if (!strcmp (current, before)) {
-					g_free (current);
-					g_array_remove_index (compl, i);
-				}
-				else
-					i++;
-			}
-
 			gchar **ptr;
 			ptr = (gchar**) compl->data;
 			g_array_free (compl, FALSE);
@@ -1823,9 +1786,6 @@ gda_sql_identifier_quote (const gchar *id, GdaConnection *cnc, GdaServerProvider
 			prov = gda_connection_get_provider (cnc);
 	}
 
-	if ((*id == '*') && (! id [1]))
-	    return g_strdup (id);
-
 	if (prov && PROV_CLASS (prov)->identifier_quote)
 		return PROV_CLASS (prov)->identifier_quote (prov, cnc, id,
 							    for_meta_store, force_quotes);
@@ -2096,7 +2056,7 @@ gda_rfc1738_decode (gchar *string)
  *
  * Extract the DSN, username and password from @string. in @string, the various parts are strings
  * which are expected to be encoded using an RFC 1738 compliant encoding. If they are specified, 
- * the returned username and password strings are correclty decoded.
+ * the returned username and password strings are correctly decoded.
  *
  * @out_username and @out_password may be set to %NULL depending on @string's format.
  */
@@ -2146,7 +2106,7 @@ gda_dsn_split (const gchar *string, gchar **out_dsn, gchar **out_username, gchar
  * Extract the provider, connection parameters, username and password from @string. 
  * in @string, the various parts are strings
  * which are expected to be encoded using an RFC 1738 compliant encoding. If they are specified, 
- * the returned provider, username and password strings are correclty decoded.
+ * the returned provider, username and password strings are correctly decoded.
  */
 void
 gda_connection_string_split (const gchar *string, gchar **out_cnc_params, gchar **out_provider, 
