@@ -47,8 +47,8 @@ typedef struct {
 	gchar               *customized_ui;
 } PerspectiveData;
 #define PERSPECTIVE_DATA(x) ((PerspectiveData*)(x))
-PerspectiveData *perspective_data_new (BrowserWindow *bwin, BrowserPerspectiveFactory *factory);
-void         perspective_data_free (PerspectiveData *pers);
+static PerspectiveData *perspective_data_new (BrowserWindow *bwin, BrowserPerspectiveFactory *factory);
+static void         perspective_data_free (PerspectiveData *pers);
 
 /* 
  * Main static functions 
@@ -206,6 +206,7 @@ static const GtkActionEntry ui_actions[] = {
         { "ConnectionMetaSync", GTK_STOCK_REFRESH, "_Fetch meta data", NULL, "Fetch meta data", G_CALLBACK (connection_meta_update_cb)},
         { "ConnectionClose", GTK_STOCK_CLOSE, "_Close connection", NULL, "Close this connection", G_CALLBACK (connection_close_cb)},
         { "Quit", GTK_STOCK_QUIT, "_Quit", NULL, "Quit", G_CALLBACK (quit_cb)},
+        { "Edit", NULL, "_Edit", NULL, "Edit", NULL },
         { "Perspective", NULL, "_Perspective", NULL, "Perspective", NULL },
         { "Window", NULL, "_Window", NULL, "Window", NULL },
         { "WindowNew", STOCK_NEW_WINDOW, "_New window", NULL, "Open a new window for current connection", G_CALLBACK (window_new_cb)},
@@ -227,6 +228,8 @@ static const gchar *ui_actions_info =
         "      <menuitem name='Quit' action= 'Quit'/>"
         "      <separator/>"
         "    </menu>"
+        "    <menu name='Edit' action='Edit'>"
+        "    </menu>"
         "    <menu name='Perspective' action='Perspective'>"
         "      <placeholder name='PersList'/>"
         "    </menu>"
@@ -253,10 +256,17 @@ static const gchar *ui_actions_info =
 
 /**
  * browser_window_new
- * @bcnc:
- * @factory: may be %NULL
+ * @bcnc: a #BrowserConnection
+ * @factory: a #BrowserPerspectiveFactory, may be %NULL
  *
- * Creates a new #BrowserWindow object, and displays it
+ * Creates a new #BrowserWindow window for the @bcnc connection, and displays it.
+ * If @factory is not %NULL, then the new window will show the perspective corresponding
+ * to @factory. If it's %NULL, then the default #BrowserPerspectiveFactory will be used,
+ * see browser_core_get_default_factory().
+ *
+ * Don't forget to call browser_core_take_window() to have the new window correctly
+ * managed by the browser. Similarly, to close the window, use browser_core_close_window()
+ * and not simply gtk_widget_destroy().
  *
  * Returns: the new object
  */
@@ -283,7 +293,7 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 	/* icon */
 	GdkPixbuf *icon;
         gchar *path;
-        path = gda_gbr_get_file_path (GDA_DATA_DIR, "pixmaps", "gda-browser.png", NULL);
+        path = gda_gbr_get_file_path (GDA_DATA_DIR, LIBGDA_ABI_NAME, "pixmaps", "gda-browser.png", NULL);
         icon = gdk_pixbuf_new_from_file (path, NULL);
         g_free (path);
         if (icon) {
@@ -393,6 +403,7 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 	pers->page_number = gtk_notebook_append_page (bwin->priv->perspectives_nb,
 						      GTK_WIDGET (pers->perspective_widget), NULL);
         gtk_widget_show_all ((GtkWidget*) bwin->priv->perspectives_nb);
+	gtk_widget_grab_focus (GTK_WIDGET (pers->perspective_widget));
 
 	/* build the perspectives menu */
 	GtkActionGroup *agroup;
@@ -768,7 +779,7 @@ about_cb (GtkAction *action, BrowserWindow *bwin)
         const gchar *translator_credits = "";
 
         gchar *path;
-        path = gda_gbr_get_file_path (GDA_DATA_DIR, "pixmaps", "gda-browser.png", NULL);
+        path = gda_gbr_get_file_path (GDA_DATA_DIR, LIBGDA_ABI_NAME, "pixmaps", "gda-browser.png", NULL);
         icon = gdk_pixbuf_new_from_file (path, NULL);
         g_free (path);
 
@@ -792,6 +803,9 @@ about_cb (GtkAction *action, BrowserWindow *bwin)
 
 /**
  * browser_window_get_connection
+ * @bwin: a #BrowserWindow
+ * 
+ * Returns: the #BrowserConnection used in @bwin
  */
 BrowserConnection *
 browser_window_get_connection (BrowserWindow *bwin)
@@ -801,7 +815,7 @@ browser_window_get_connection (BrowserWindow *bwin)
 }
 
 
-/**
+/*
  * perspective_data_new
  * @bwin: a #BrowserWindow in which the perspective will be
  * @factory: a #BrowserPerspectiveFactory, or %NULL
@@ -810,7 +824,7 @@ browser_window_get_connection (BrowserWindow *bwin)
  *
  * Returns: a new #PerspectiveData
  */
-PerspectiveData *
+static PerspectiveData *
 perspective_data_new (BrowserWindow *bwin, BrowserPerspectiveFactory *factory)
 {
         PerspectiveData *pers;
@@ -827,10 +841,10 @@ perspective_data_new (BrowserWindow *bwin, BrowserPerspectiveFactory *factory)
         return pers;
 }
 
-/**
+/*
  * perspective_data_free
  */
-void
+static void
 perspective_data_free (PerspectiveData *pers)
 {
         if (pers->perspective_widget)
@@ -843,6 +857,13 @@ perspective_data_free (PerspectiveData *pers)
 
 /**
  * browser_window_push_status
+ * @bwin: a #BrowserWindow
+ * @context: textual description of what context the new message is being used in
+ * @text: textual message
+ *
+ * Pushes a new message onto @bwin's statusbar's stack.
+ *
+ * Returns: the message ID, see gtk_statusbar_push().
  */
 guint
 browser_window_push_status (BrowserWindow *bwin, const gchar *context, const gchar *text)
@@ -859,6 +880,10 @@ browser_window_push_status (BrowserWindow *bwin, const gchar *context, const gch
 
 /**
  * browser_window_pop_status
+ * @bwin: a #BrowserWindow
+ * @context: textual description of what context the message is being used in
+ *
+ * Removes the first message in the @bwin's statusbar's stack with the given context.
  */
 void
 browser_window_pop_status (BrowserWindow *bwin, const gchar *context)
@@ -873,7 +898,11 @@ browser_window_pop_status (BrowserWindow *bwin, const gchar *context)
 }
 
 /**
- * browser_window_push_perspective_ui
+ * browser_window_customize_perspective_ui
+ * @bwin: a #BrowserWindow
+ * @bpers: the #BrowserPerspective concerned
+ * @actions_group: a #GtkActionGroup object, or %NULL
+ * @ui_info: a merge UI string, or %NULL. See gtk_ui_manager_add_ui_from_string()
  *
  * Customizes a UI specific to the @bpers perspective. Any
  * previous customization is removed, replaced by the new requested one.
@@ -904,7 +933,6 @@ browser_window_customize_perspective_ui (BrowserWindow *bwin, BrowserPerspective
 	if (pdata->customized_merge_id) {
 		gtk_ui_manager_remove_ui (bwin->priv->ui_manager, pdata->customized_merge_id);
 		pdata->customized_merge_id = 0;
-		gtk_ui_manager_ensure_update (bwin->priv->ui_manager);
 	}
 	if (pdata->customized_actions) {
 		gtk_ui_manager_remove_action_group (bwin->priv->ui_manager, pdata->customized_actions);
@@ -913,6 +941,7 @@ browser_window_customize_perspective_ui (BrowserWindow *bwin, BrowserPerspective
 	}
 	g_free (pdata->customized_ui);
 	pdata->customized_ui = NULL;
+	gtk_ui_manager_ensure_update (bwin->priv->ui_manager);
 
 	if (actions_group) {
 		g_return_if_fail (GTK_IS_ACTION_GROUP (actions_group));
